Module blaxel.pydantic.tools
============================

Functions
---------

`bl_tools(tools_names: list[str], **kwargs) ‑> list[pydantic_ai.tools.Tool]`
:   

`get_pydantic_tool(tool: blaxel.core.tools.types.Tool) ‑> pydantic_ai.tools.Tool`
:   Converts a custom Tool object into a Pydantic AI Tool object.
    
    Uses the attributes defined in the custom Tool (name, description, input_schema)
    by defining a dynamic 'prepare' function that modifies the ToolDefinition
    generated by Pydantic AI.